︠59961ad1-5ce5-41a8-bc7a-d9bf48712e0asir︠
### Simulates Lotka-Volterra population dynamics, producing a vector field
### Arrows indicate the direction of population evolution
### The blue contour is one potential stable loop
from sage.plot.point import Point
var('t X Y X0 Y0  g1 g2 phi b r')
## CONSTANTS
#r = 1.1         # ratio of birthrate over Y over X
#g1 = 1.1    #competition factor for X
#g2 = 1.5    #competition factor for Y
#b = 0.82  #How toxic the toxin is
#phi = .03   #natural death rate of X
#c = 0.1    #concentration of toxic in environment

#d = 1 - ((1-b)*phi*c)/(1-c)
#X0 = 0.5
#Y0 = 0.5
#show(d)

@interact
def _(r = input_box(default=1), g1=input_box(default= 1.1),
      g2=input_box(default=1.5), d=input_box(default=0.8),
      c=(0.1, (0, 1)),
      X0=input_box(default=0.5), Y0=input_box(default=0.5),
      ):
    
## DIFFERENTIAL EQUATIONS
    de_X = (diff(X,t) == (1-c)*X*(d -X - g1*Y))
    de_Y = (diff(Y,t) == r*Y*(1-Y-g2*X))

## CALCULATION PARAMETERS
    end_points = 1000
    stepsize = 1.0
    steps = end_points/stepsize
    ics = [0,X0,Y0]
    des = [de_X.rhs(), de_Y.rhs()]

## NUMERICAL SOLUTION OF DIFFERENTIAL EQUATIONS
    sol = desolve_system_rk4(des,[X,Y],ics,ivar=t,end_points=end_points,step=stepsize)

## Clean up to graph
    sol_t=[]; sol_X=[]; sol_Y=[]
    for i in range(steps):
        sol_t.append(sol[i][0])
        sol_X.append(sol[i][1])
        sol_Y.append(sol[i][2])
    #d = (1 - ((1-b)*phi*c)/(1-c))
    #print 'delta = ',d
    #print((d - g1)/(1-g1*g2), (1-d*g2)/(1-g1*g2))
    a = plot([],figsize=[5,3])
    a += line(zip(sol_X,sol_Y))
    a += plot_vector_field((des[0], des[1]), (X,0,1), (Y,0,1),color='black')
    a.axes_labels(['X','Y']); show(a)
︡c39139f4-e712-49ea-87e3-69cb3e91685a︡
︠2188c1ca-e1d1-4182-a50a-ed0314685519si︠

P=line([(0.6,0), (0.6, 1)], color = 'black')
P += line([(0,0.6), (1, 0.6)], color='black')
P+= text("Unstable", (.3, .8), fontsize=20, color='black')
P+= text("X Wins", (.3,.3), fontsize=20, color='black')
P+= text("Y Wins", (.8,.8), fontsize=20, color='black')
P+= text("Both Stable", (.8,.3), fontsize=20, color='black')
P+= text("$\gamma_1$", (0.9,-.2), fontsize=20, color='black')
P+= text("${1}/{\gamma_2}$", (-.1,0.8), fontsize=20, color='black')
P+= text("$\delta$", (0.6,-.2), fontsize=20, color='red')
P+= text("$\delta$", (-0.075,0.6), fontsize=20, color='red')
show(P)
︡3c04e81d-a7f3-4c94-8b91-4a123b9c9937︡{"file":{"filename":"/projects/7cec8836-62a4-4893-86c3-3321cf5085f4/.sage/temp/compute0-us/25372/tmp_P_uYtF.svg","show":true,"text":null,"uuid":"0d8cd341-d072-44fe-a114-199e56157695"},"once":false}︡{"done":true}︡











